Another Document
================

This document is just like the others.

.. _mountain:

.. figure:: https://upload.wikimedia.org/wikipedia/commons/f/f9/Rainier20200906.jpg

   An image of Seattle's Rainer mountain.
